from datetime import datetime
from pytest import mark

from homeconnect_watcher.db import WatcherDBClient


class TestCoffeeMaker:
    pass


class TestWasher:
    @mark.events(
        """
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "CONNECTED", "timestamp": 1704972036, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "handling": "none", "key": "BSH.Common.Appliance.Connected", "level": "hint", "timestamp": 1704972036, "value": true}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "STATUS-REQUEST", "timestamp": 1704972038, "data": {"status": [{"key": "BSH.Common.Status.DoorState", "value": "BSH.Common.EnumType.DoorState.Locked"}, {"key": "BSH.Common.Status.LocalControlActive", "value": false}, {"key": "BSH.Common.Status.OperationState", "value": "BSH.Common.EnumType.OperationState.Run"}, {"key": "BSH.Common.Status.RemoteControlActive", "value": true}, {"key": "BSH.Common.Status.RemoteControlStartAllowed", "value": false}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "SETTINGS-REQUEST", "timestamp": 1704972040, "data": {"settings": [{"key": "BSH.Common.Setting.PowerState", "value": "BSH.Common.EnumType.PowerState.On"}, {"key": "LaundryCare.Washer.Setting.IDos1BaseLevel", "value": 30, "unit": "ml"}, {"key": "LaundryCare.Washer.Setting.IDos2BaseLevel", "value": 30, "unit": "ml"}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "ACTIVE-PROGRAM-REQUEST", "timestamp": 1704972041, "data": {"constraints": {"access": "read"}, "key": "LaundryCare.Washer.Program.Cotton", "options": [{"key": "LaundryCare.Common.Option.LoadRecommendation", "value": 8000, "unit": "gram"}, {"key": "LaundryCare.Common.Option.VarioPerfect", "value": "LaundryCare.Common.EnumType.VarioPerfect.Off"}, {"key": "LaundryCare.Washer.Option.IDos1DosingLevel", "value": "LaundryCare.Washer.EnumType.IDosingLevel.Normal"}, {"key": "LaundryCare.Washer.Option.IDos2DosingLevel", "value": "LaundryCare.Washer.EnumType.IDosingLevel.Light"}, {"key": "LaundryCare.Washer.Option.LessIroning", "value": false}, {"key": "LaundryCare.Washer.Option.Prewash", "value": false}, {"key": "LaundryCare.Washer.Option.SpinSpeed", "value": "LaundryCare.Washer.EnumType.SpinSpeed.RPM1200"}, {"key": "LaundryCare.Washer.Option.Temperature", "value": "LaundryCare.Washer.EnumType.Temperature.GC60"}, {"key": "LaundryCare.Washer.Option.WaterAndRinsePlus", "value": "LaundryCare.Washer.EnumType.WaterAndRinsePlus.Off"}, {"key": "BSH.Common.Option.ProgramProgress", "value": 0, "unit": "%"}, {"key": "BSH.Common.Option.RemainingProgramTime", "value": 8277, "unit": "seconds"}, {"key": "BSH.Common.Option.RemainingProgramTimeIsEstimated", "value": true}, {"key": "LaundryCare.Washer.Option.ProcessPhase", "value": "LaundryCare.Washer.EnumType.ProcessPhase.Washing"}, {"key": "BSH.Common.Option.EnergyForecast", "value": 80, "unit": "%"}, {"key": "BSH.Common.Option.WaterForecast", "value": 60, "unit": "%"}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "SELECTED-PROGRAM-REQUEST", "timestamp": 1704972043, "data": {"constraints": {"access": "read"}, "key": "LaundryCare.Washer.Program.Cotton", "options": [{"key": "LaundryCare.Common.Option.LoadRecommendation", "value": 8000, "unit": "gram"}, {"key": "LaundryCare.Common.Option.VarioPerfect", "value": "LaundryCare.Common.EnumType.VarioPerfect.Off"}, {"key": "LaundryCare.Washer.Option.IDos1DosingLevel", "value": "LaundryCare.Washer.EnumType.IDosingLevel.Normal"}, {"key": "LaundryCare.Washer.Option.IDos2DosingLevel", "value": "LaundryCare.Washer.EnumType.IDosingLevel.Light"}, {"key": "LaundryCare.Washer.Option.LessIroning", "value": false}, {"key": "LaundryCare.Washer.Option.Prewash", "value": false}, {"key": "LaundryCare.Washer.Option.SpinSpeed", "value": "LaundryCare.Washer.EnumType.SpinSpeed.RPM1200"}, {"key": "LaundryCare.Washer.Option.Temperature", "value": "LaundryCare.Washer.EnumType.Temperature.GC60"}, {"key": "LaundryCare.Washer.Option.WaterAndRinsePlus", "value": "LaundryCare.Washer.EnumType.WaterAndRinsePlus.Off"}, {"key": "BSH.Common.Option.RemainingProgramTime", "value": 8276, "unit": "seconds"}, {"key": "BSH.Common.Option.RemainingProgramTimeIsEstimated", "value": true}, {"key": "BSH.Common.Option.EnergyForecast", "value": 80, "unit": "%"}, {"key": "BSH.Common.Option.WaterForecast", "value": 60, "unit": "%"}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "STATUS", "timestamp": 1704972043, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Status.LocalControlActive", "level": "hint", "timestamp": 1704972036, "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/status/BSH.Common.Status.LocalControlActive", "value": false}, {"handling": "none", "key": "BSH.Common.Status.RemoteControlActive", "level": "hint", "timestamp": 1704972036, "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/status/BSH.Common.Status.RemoteControlActive", "value": true}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1704972093, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.RemainingProgramTime", "level": "hint", "timestamp": 1704972093, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.RemainingProgramTime", "value": 8220}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1704974129, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.RemainingProgramTime", "level": "hint", "timestamp": 1704974129, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.RemainingProgramTime", "value": 4080}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1704976349, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.RemainingProgramTime", "level": "hint", "timestamp": 1704976349, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.RemainingProgramTime", "value": 1860}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1704979640, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.RemainingProgramTime", "level": "hint", "timestamp": 1704979640, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.RemainingProgramTime", "value": 0}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "STATUS", "timestamp": 1704979641, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Status.OperationState", "level": "hint", "timestamp": 1704979641, "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/status/BSH.Common.Status.OperationState", "value": "BSH.Common.EnumType.OperationState.Finished"}, {"handling": "none", "key": "BSH.Common.Status.DoorState", "level": "hint", "timestamp": 1704979641, "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/status/BSH.Common.Status.DoorState", "value": "BSH.Common.EnumType.DoorState.Closed"}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "EVENT", "timestamp": 1704979641, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "acknowledge", "key": "BSH.Common.Event.ProgramFinished", "level": "hint", "timestamp": 1704979641, "value": "BSH.Common.EnumType.EventPresentState.Present"}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1704979642, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.FinishInRelative", "level": "hint", "timestamp": 1704979642, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.FinishInRelative", "value": 0}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "DISCONNECTED", "timestamp": 1704993381, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "handling": "none", "key": "BSH.Common.Appliance.Disconnected", "level": "hint", "timestamp": 1704993381, "value": true}}
"""
    )
    def test_simple_session(self, db_with_events: WatcherDBClient):
        db_with_events.cursor.execute(
            "SELECT appliance_id, trigger_time, start_time, end_time, program FROM v_sessions"
        )
        result = db_with_events.cursor.fetchall()
        assert len(result) == 1
        assert result[0] == (
            "SIEMENS-WM14T6H9NL-AB1234567890",
            datetime(2024, 1, 11, 12, 20, 38),
            datetime(2024, 1, 11, 12, 20, 38),
            datetime(2024, 1, 11, 14, 27, 20),
            "Cotton",
        )

    @mark.events(
        """
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707382868, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.FinishInRelative", "level": "hint", "timestamp": 1707382868, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/selected/options/BSH.Common.Option.FinishInRelative", "value": 84600}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "STATUS", "timestamp": 1707382871, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Status.DoorState", "level": "hint", "timestamp": 1707382871, "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/status/BSH.Common.Status.DoorState", "value": "BSH.Common.EnumType.DoorState.Locked"}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "STATUS", "timestamp": 1707382872, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Status.OperationState", "level": "hint", "timestamp": 1707382872, "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/status/BSH.Common.Status.OperationState", "value": "BSH.Common.EnumType.OperationState.DelayedStart"}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707382872, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.RemainingProgramTime", "level": "hint", "timestamp": 1707382872, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.RemainingProgramTime", "value": 12660}, {"handling": "none", "key": "BSH.Common.Root.ActiveProgram", "level": "hint", "timestamp": 1707382872, "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active", "value": "LaundryCare.Washer.Program.Cotton.CottonEco"}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "STATUS", "timestamp": 1707382874, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Status.LocalControlActive", "level": "hint", "timestamp": 1707382874, "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/status/BSH.Common.Status.LocalControlActive", "value": false}, {"handling": "none", "key": "BSH.Common.Status.RemoteControlActive", "level": "hint", "timestamp": 1707382874, "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/status/BSH.Common.Status.RemoteControlActive", "value": true}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707382931, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.FinishInRelative", "level": "hint", "timestamp": 1707382931, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.FinishInRelative", "value": 84540}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707382991, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.FinishInRelative", "level": "hint", "timestamp": 1707382991, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.FinishInRelative", "value": 84480}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707383051, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.FinishInRelative", "level": "hint", "timestamp": 1707383051, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.FinishInRelative", "value": 84420}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "STATUS-REQUEST", "timestamp": 1707383053, "data": {"status": [{"key": "BSH.Common.Status.DoorState", "value": "BSH.Common.EnumType.DoorState.Locked"}, {"key": "BSH.Common.Status.LocalControlActive", "value": false}, {"key": "BSH.Common.Status.OperationState", "value": "BSH.Common.EnumType.OperationState.DelayedStart"}, {"key": "BSH.Common.Status.RemoteControlActive", "value": true}, {"key": "BSH.Common.Status.RemoteControlStartAllowed", "value": false}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707383111, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.FinishInRelative", "level": "hint", "timestamp": 1707383111, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.FinishInRelative", "value": 84360}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707384131, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.FinishInRelative", "level": "hint", "timestamp": 1707384131, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.FinishInRelative", "value": 83340}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707385510, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.FinishInRelative", "level": "hint", "timestamp": 1707385510, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.FinishInRelative", "value": 81960}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707386769, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.FinishInRelative", "level": "hint", "timestamp": 1707386769, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.FinishInRelative", "value": 80700}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707388088, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.FinishInRelative", "level": "hint", "timestamp": 1707388088, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.FinishInRelative", "value": 79380}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707389348, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.FinishInRelative", "level": "hint", "timestamp": 1707389348, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.FinishInRelative", "value": 78120}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707391986, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.FinishInRelative", "level": "hint", "timestamp": 1707391986, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.FinishInRelative", "value": 75480}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707393245, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.FinishInRelative", "level": "hint", "timestamp": 1707393245, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.FinishInRelative", "value": 74220}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707394564, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.FinishInRelative", "level": "hint", "timestamp": 1707394564, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.FinishInRelative", "value": 72900}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707395824, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.FinishInRelative", "level": "hint", "timestamp": 1707395823, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.FinishInRelative", "value": 71640}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707398342, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.FinishInRelative", "level": "hint", "timestamp": 1707398342, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.FinishInRelative", "value": 69120}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707399661, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.FinishInRelative", "level": "hint", "timestamp": 1707399661, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.FinishInRelative", "value": 67800}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707400980, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.FinishInRelative", "level": "hint", "timestamp": 1707400980, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.FinishInRelative", "value": 66480}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707402239, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.FinishInRelative", "level": "hint", "timestamp": 1707402239, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.FinishInRelative", "value": 65220}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707403559, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.FinishInRelative", "level": "hint", "timestamp": 1707403559, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.FinishInRelative", "value": 63900}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707404818, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.FinishInRelative", "level": "hint", "timestamp": 1707404818, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.FinishInRelative", "value": 62640}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707406137, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.FinishInRelative", "level": "hint", "timestamp": 1707406137, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.FinishInRelative", "value": 61320}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707407456, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.FinishInRelative", "level": "hint", "timestamp": 1707407456, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.FinishInRelative", "value": 60000}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707408715, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.FinishInRelative", "level": "hint", "timestamp": 1707408715, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.FinishInRelative", "value": 58740}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707410094, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.FinishInRelative", "level": "hint", "timestamp": 1707410094, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.FinishInRelative", "value": 57360}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707411414, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.FinishInRelative", "level": "hint", "timestamp": 1707411414, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.FinishInRelative", "value": 56040}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707413452, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.FinishInRelative", "level": "hint", "timestamp": 1707413452, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.FinishInRelative", "value": 54000}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707415431, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.FinishInRelative", "level": "hint", "timestamp": 1707415431, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.FinishInRelative", "value": 52020}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707417410, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.FinishInRelative", "level": "hint", "timestamp": 1707417410, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.FinishInRelative", "value": 50040}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707419449, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.FinishInRelative", "level": "hint", "timestamp": 1707419449, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.FinishInRelative", "value": 48000}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707421427, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.FinishInRelative", "level": "hint", "timestamp": 1707421427, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.FinishInRelative", "value": 46020}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707423406, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.FinishInRelative", "level": "hint", "timestamp": 1707423406, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.FinishInRelative", "value": 44040}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707425445, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.FinishInRelative", "level": "hint", "timestamp": 1707425445, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.FinishInRelative", "value": 42000}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707427424, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.FinishInRelative", "level": "hint", "timestamp": 1707427424, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.FinishInRelative", "value": 40020}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707429403, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.FinishInRelative", "level": "hint", "timestamp": 1707429403, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.FinishInRelative", "value": 38040}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707431441, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.FinishInRelative", "level": "hint", "timestamp": 1707431441, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.FinishInRelative", "value": 36000}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707433420, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.FinishInRelative", "level": "hint", "timestamp": 1707433420, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.FinishInRelative", "value": 34020}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707435399, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.FinishInRelative", "level": "hint", "timestamp": 1707435399, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.FinishInRelative", "value": 32040}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707437438, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.FinishInRelative", "level": "hint", "timestamp": 1707437438, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.FinishInRelative", "value": 30000}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707439417, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.FinishInRelative", "level": "hint", "timestamp": 1707439416, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.FinishInRelative", "value": 28020}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707441395, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.FinishInRelative", "level": "hint", "timestamp": 1707441395, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.FinishInRelative", "value": 26040}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707443434, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.FinishInRelative", "level": "hint", "timestamp": 1707443434, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.FinishInRelative", "value": 24000}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707445293, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.FinishInRelative", "level": "hint", "timestamp": 1707445293, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.FinishInRelative", "value": 22140}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707447392, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.FinishInRelative", "level": "hint", "timestamp": 1707447392, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.FinishInRelative", "value": 20040}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707449251, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.FinishInRelative", "level": "hint", "timestamp": 1707449251, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.FinishInRelative", "value": 18180}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707451409, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.FinishInRelative", "level": "hint", "timestamp": 1707451409, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.FinishInRelative", "value": 16020}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707453388, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.FinishInRelative", "level": "hint", "timestamp": 1707453388, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.FinishInRelative", "value": 14040}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "STATUS", "timestamp": 1707453868, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Status.OperationState", "level": "hint", "timestamp": 1707453868, "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/status/BSH.Common.Status.OperationState", "value": "BSH.Common.EnumType.OperationState.Run"}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707454527, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.RemainingProgramTime", "level": "hint", "timestamp": 1707454527, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.RemainingProgramTime", "value": 12000}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707456159, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.RemainingProgramTime", "level": "hint", "timestamp": 1707456159, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.RemainingProgramTime", "value": 10020}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707458138, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.RemainingProgramTime", "level": "hint", "timestamp": 1707458138, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.RemainingProgramTime", "value": 8040}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707460177, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.RemainingProgramTime", "level": "hint", "timestamp": 1707460177, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.RemainingProgramTime", "value": 6000}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707462096, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.RemainingProgramTime", "level": "hint", "timestamp": 1707462096, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.RemainingProgramTime", "value": 4080}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707464291, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.RemainingProgramTime", "level": "hint", "timestamp": 1707464291, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.RemainingProgramTime", "value": 2040}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707466275, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.RemainingProgramTime", "level": "hint", "timestamp": 1707466275, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.RemainingProgramTime", "value": 0}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "EVENT", "timestamp": 1707466275, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "acknowledge", "key": "LaundryCare.Washer.Event.IDos1FillLevelPoor", "level": "warning", "timestamp": 1707466275, "value": "BSH.Common.EnumType.EventPresentState.Present"}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "EVENT", "timestamp": 1707466277, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "acknowledge", "key": "BSH.Common.Event.ProgramFinished", "level": "hint", "timestamp": 1707466277, "value": "BSH.Common.EnumType.EventPresentState.Present"}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "STATUS", "timestamp": 1707466277, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Status.OperationState", "level": "hint", "timestamp": 1707466277, "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/status/BSH.Common.Status.OperationState", "value": "BSH.Common.EnumType.OperationState.Finished"}, {"handling": "none", "key": "BSH.Common.Status.DoorState", "level": "hint", "timestamp": 1707466277, "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/status/BSH.Common.Status.DoorState", "value": "BSH.Common.EnumType.DoorState.Closed"}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707466277, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.FinishInRelative", "level": "hint", "timestamp": 1707466277, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active/options/BSH.Common.Option.FinishInRelative", "value": 0}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "EVENT", "timestamp": 1707467283, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "acknowledge", "key": "BSH.Common.Event.ProgramFinished", "level": "hint", "timestamp": 1707467283, "value": "BSH.Common.EnumType.EventPresentState.Off"}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "STATUS-REQUEST", "timestamp": 1707467287, "data": {"status": [{"key": "BSH.Common.Status.DoorState", "value": "BSH.Common.EnumType.DoorState.Open"}, {"key": "BSH.Common.Status.LocalControlActive", "value": true}, {"key": "BSH.Common.Status.OperationState", "value": "BSH.Common.EnumType.OperationState.Ready"}, {"key": "BSH.Common.Status.RemoteControlActive", "value": false}, {"key": "BSH.Common.Status.RemoteControlStartAllowed", "value": false}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "STATUS", "timestamp": 1707467287, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Status.OperationState", "level": "hint", "timestamp": 1707467283, "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/status/BSH.Common.Status.OperationState", "value": "BSH.Common.EnumType.OperationState.Ready"}, {"handling": "none", "key": "BSH.Common.Status.DoorState", "level": "hint", "timestamp": 1707467283, "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/status/BSH.Common.Status.DoorState", "value": "BSH.Common.EnumType.DoorState.Open"}, {"handling": "none", "key": "BSH.Common.Status.LocalControlActive", "level": "hint", "timestamp": 1707467283, "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/status/BSH.Common.Status.LocalControlActive", "value": true}, {"handling": "none", "key": "BSH.Common.Status.RemoteControlActive", "level": "hint", "timestamp": 1707467283, "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/status/BSH.Common.Status.RemoteControlActive", "value": false}]}}
{"appliance_id": "SIEMENS-WM14T6H9NL-AB1234567890", "event": "NOTIFY", "timestamp": 1707467287, "data": {"haId": "SIEMENS-WM14T6H9NL-AB1234567890", "items": [{"handling": "none", "key": "BSH.Common.Option.EstimatedTotalProgramTime", "level": "hint", "timestamp": 1707467283, "unit": "seconds", "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/selected/options/BSH.Common.Option.EstimatedTotalProgramTime", "value": 0}, {"handling": "none", "key": "BSH.Common.Root.ActiveProgram", "level": "hint", "timestamp": 1707467283, "uri": "/api/homeappliances/SIEMENS-WM14T6H9NL-AB1234567890/programs/active", "value": null}]}}
"""
    )
    def test_delayed_session(self, db_with_events: WatcherDBClient):
        db_with_events.cursor.execute(
            "SELECT appliance_id, trigger_time, start_time, end_time, program FROM v_sessions"
        )
        result = db_with_events.cursor.fetchall()
        assert len(result) == 1
        assert result[0] == (
            "SIEMENS-WM14T6H9NL-AB1234567890",
            datetime(2024, 2, 8, 10, 1, 12),
            datetime(2024, 2, 9, 5, 44, 28),
            datetime(2024, 2, 9, 9, 11, 15),
            "CottonEco",
        )


class TestDryer:
    pass
